about summary refs log tree commit diff
path: root/pkgs/tools/graphics/gifski/default.nix
diff options
context:
space:
mode:
authorTheodore Ni <3806110+tjni@users.noreply.github.com>2023-08-07 02:06:37 -0700
committerTheodore Ni <3806110+tjni@users.noreply.github.com>2023-08-07 18:28:51 -0700
commit44dddc3f18032917bbacb93dcce178f3f819a682 (patch)
tree5852880d0c9e6790e90b434b0cc51c0416dc313d /pkgs/tools/graphics/gifski/default.nix
parent2ac27de2bc9bbc2d73a93508962a28c520f4fac5 (diff)
gifski: fix tests by running them in debug mode
Diffstat (limited to 'pkgs/tools/graphics/gifski/default.nix')
-rw-r--r--pkgs/tools/graphics/gifski/default.nix14
1 files changed, 11 insertions, 3 deletions
diff --git a/pkgs/tools/graphics/gifski/default.nix b/pkgs/tools/graphics/gifski/default.nix
index 60a77af920ea8..437bb414ef3d2 100644
--- a/pkgs/tools/graphics/gifski/default.nix
+++ b/pkgs/tools/graphics/gifski/default.nix
@@ -14,7 +14,7 @@ rustPlatform.buildRustPackage rec {
     owner = "ImageOptim";
     repo = "gifski";
     rev = version;
-    sha256 = "sha256-sPsq/hntNqOdPJcoob1jrDUrLLiBEnfRoDANyFUjOuM=";
+    hash = "sha256-sPsq/hntNqOdPJcoob1jrDUrLLiBEnfRoDANyFUjOuM=";
   };
 
   cargoLock = {
@@ -35,8 +35,15 @@ rustPlatform.buildRustPackage rec {
 
   buildFeatures = [ "video" ];
 
-  # error: the crate `gifski` is compiled with the panic strategy `abort` which is incompatible with this crate's strategy of `unwind`
-  doCheck = !stdenv.isDarwin;
+  # When the default checkType of release is used, we get the following error:
+  #
+  #   error: the crate `gifski` is compiled with the panic strategy `abort` which
+  #   is incompatible with this crate's strategy of `unwind`
+  #
+  # It looks like https://github.com/rust-lang/cargo/issues/6313, which does not
+  # outline a solution.
+  #
+  checkType = "debug";
 
   # error: linker `/usr/bin/x86_64-linux-gnu-gcc` not found
   postPatch = ''
@@ -49,5 +56,6 @@ rustPlatform.buildRustPackage rec {
     changelog = "https://github.com/ImageOptim/gifski/releases/tag/${src.rev}";
     license = licenses.agpl3Plus;
     maintainers = with maintainers; [ figsoda marsam ];
+    mainProgram = "gifski";
   };
 }